from machine import Pin, ADC
from machine import Pin, I2C
import time
import network
import ssd1306
import math
from config import (
    WIFI_SSID, WIFI_PASS,
    MQTT_BROKER, MQTT_USER, MQTT_PASS,
    TOPIC_PREFIX
)
from umqtt.simple import MQTTClient
from time import sleep

import MQ2
import utime

class App:
    def __init__(self, pin = 8):
        self.sensor = MQ2.MQ2(pinData = pin, baseVoltage = 3.3)

    def Run(self):
        print("Calibrating")
        self.sensor.calibrate()
        mqtt.publish(Smoke, str(self.sensor.readSmoke()))
        mqtt.publish(LPG, str(self.sensor.readLPG()))
        utime.sleep(1)



Smoke = f'{TOPIC_PREFIX}/smoke'
LPG = f'{TOPIC_PREFIX}/lpg'
i2c = I2C(0, sda=Pin(48), scl=Pin(47))




def connect_wifi():
    mac = ':'.join(f'{b:02X}' for b in wifi.config('mac'))
    print(f'WiFi MAC address is {mac}')
    wifi.active(True)
    print(f'Connecting to WiFi {WIFI_SSID}.')
    wifi.connect(WIFI_SSID, WIFI_PASS)
    while not wifi.isconnected():
        print('.', end='')
        time.sleep(0.5)
    print('\nWiFi connected.')




def connect_mqtt():
    print(f'Connecting to MQTT broker at {MQTT_BROKER}.')
    mqtt.connect()
    mqtt.set_callback(mqtt_callback)
    mqtt.subscribe(Smoke)
    mqtt.subscribe(LPG)
    print('MQTT broker connected.')




def mqtt_callback(topic, payload):
    pass




############
# setup
############

wifi = network.WLAN(network.STA_IF)
mqtt = MQTTClient(client_id='',
                  server=MQTT_BROKER,
                  user=MQTT_USER,
                  password=MQTT_PASS)
connect_wifi()
connect_mqtt()
last_publish = 0
x = 0


############
# loop
############
while True:
    # check for incoming subscribed topics
    mqtt.check_msg()
    # publish light value periodically (without using sleep)
    now = time.ticks_ms()
    App().Run()
        